summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgamelcd.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgamelcd.h')
-rw-r--r--libkdegames/kgamelcd.h76
1 files changed, 38 insertions, 38 deletions
diff --git a/libkdegames/kgamelcd.h b/libkdegames/kgamelcd.h
index 3e6ad33c..f7d2c58d 100644
--- a/libkdegames/kgamelcd.h
+++ b/libkdegames/kgamelcd.h
@@ -20,8 +20,8 @@
#ifndef __KGAMELCD_H
#define __KGAMELCD_H
-#include <qlcdnumber.h>
-#include <qvaluevector.h>
+#include <tqlcdnumber.h>
+#include <tqvaluevector.h>
#include <kdemacros.h>
class QLabel;
@@ -29,7 +29,7 @@ class QTimer;
//-----------------------------------------------------------------------------
/**
* This class is a visually enhanced @ref QLCDNumber:
* <ul>
* <li> It can show an additional string before the integer being
* displayed.</li>
@@ -43,30 +43,30 @@ class KDE_EXPORT KGameLCD : public QLCDNumber
{
Q_OBJECT
public:
- KGameLCD(uint nbDigits, QWidget *parent = 0, const char *name = 0);
+ KGameLCD(uint nbDigits, TQWidget *parent = 0, const char *name = 0);
~KGameLCD();
/**
* Set the default background color.
*/
- void setDefaultBackgroundColor(const QColor &color);
+ void setDefaultBackgroundColor(const TQColor &color);
/**
* Set the default foreground color.
*/
- void setDefaultColor(const QColor &color);
+ void setDefaultColor(const TQColor &color);
/**
* Set highlight color.
*/
- void setHighlightColor(const QColor &color);
+ void setHighlightColor(const TQColor &color);
/**
* Set the string that will be displayed before the integer number to be
* displayed. By default this string is null.
*/
- void setLeadingString(const QString &s);
+ void setLeadingString(const TQString &s);
/**
* Set the highlight duration in milliseconds. The default value is
@@ -82,7 +82,7 @@ public:
/**
* Set the foreground color.
*/
- void setColor(const QColor &color);
+ void setColor(const TQColor &color);
public slots:
/**
@@ -94,8 +94,8 @@ public slots:
/**
* Display the given integer with the (optionnal) leading string.
*
* Note: we cannot use display(int) since QLCDNumber::display is
* not virtual... And you cannot use QLCDNumber::intValue() to retrieve
* the given value.
*/
void displayInt(int value);
@@ -104,10 +104,10 @@ private slots:
void timeout() { highlight(false); }
private:
- QColor _fgColor, _hlColor;
- QString _lead;
+ TQColor _fgColor, _hlColor;
+ TQString _lead;
uint _htime;
- QTimer *_timer;
+ TQTimer *_timer;
class KGameLCDPrivate;
KGameLCDPrivate *d;
@@ -127,7 +127,7 @@ class KDE_EXPORT KGameLCDClock : public KGameLCD
{
Q_OBJECT
public:
- KGameLCDClock(QWidget *parent = 0, const char *name = 0);
+ KGameLCDClock(TQWidget *parent = 0, const char *name = 0);
~KGameLCDClock();
@@ -139,7 +139,7 @@ public:
/**
* @return the time as a string to be displayed: "mm:ss".
*/
- QString pretty() const;
+ TQString pretty() const;
/**
* Set the time.
@@ -149,7 +149,7 @@ public:
/**
* Set the time (format should be "mm:ss").
*/
- void setTime(const QString &s);
+ void setTime(const TQString &s);
public slots:
/**
@@ -171,7 +171,7 @@ protected slots:
virtual void timeoutClock();
private:
- QTimer *_timerClock;
+ TQTimer *_timerClock;
uint _sec, _min;
class KGameLCDClockPrivate;
@@ -182,7 +182,7 @@ private:
//-----------------------------------------------------------------------------
/**
* This widget holds a list of @ref QLCDNumber arranged in a vertical layout.
* It also shows a label at the top of the list.
*
* @since 3.2
@@ -195,55 +195,55 @@ public:
* Constructor.
*
* @param title is the content of the top label.
* @param parent passed to the QWidget constructor
* @param name passed to the QWidget constructor
*/
- KGameLCDList(const QString &title,
- QWidget *parent = 0, const char *name = 0);
- KGameLCDList(QWidget *parent = 0, const char *name = 0);
+ KGameLCDList(const TQString &title,
+ TQWidget *parent = 0, const char *name = 0);
+ KGameLCDList(TQWidget *parent = 0, const char *name = 0);
~KGameLCDList();
/**
* Append a QLCDNumber at the bottom of the list.
* The QLCDNumber should have the KGameLCDList as parent.
*/
- void append(QLCDNumber *lcd);
+ void append(TQLCDNumber *lcd);
/**
* Append a QLCDNumber at the bottom of the list.
* The QLCDNumber should have the KGameLCDList as parent.
*/
- void append(const QString &leading, QLCDNumber *lcd);
+ void append(const TQString &leading, TQLCDNumber *lcd);
/**
* Delete all @ref QLCDNumber and clear the list.
*/
void clear();
/**
* @return the title label.
*/
- QLabel *title() const { return _title; }
+ TQLabel *title() const { return _title; }
/**
* @return the QLCDNumber at index @param i
*/
- QLCDNumber *lcd(uint i) const { return _lcds[i]; }
+ TQLCDNumber *lcd(uint i) const { return _lcds[i]; }
/**
* @return the number of QLCDNumber in the list.
*/
uint size() const { return _lcds.size(); }
private:
- QLabel *_title;
- QValueVector<QLCDNumber *> _lcds;
+ TQLabel *_title;
+ TQValueVector<TQLCDNumber *> _lcds;
class KGameLCDListPrivate;
KGameLCDListPrivate *d;
- void init(const QString &title);
+ void init(const TQString &title);
};
#endif
@@ -29,7 +29,7 @@ class QTimer;
//-----------------------------------------------------------------------------
/**
- * This class is a visually enhanced @ref QLCDNumber:
+ * This class is a visually enhanced @ref TQLCDNumber:
* <ul>
* <li> It can show an additional string before the integer being
@@ -94,8 +94,8 @@ public slots:
* Display the given integer with the (optionnal) leading string.
*
- * Note: we cannot use display(int) since QLCDNumber::display is
- * not virtual... And you cannot use QLCDNumber::intValue() to retrieve
+ * Note: we cannot use display(int) since TQLCDNumber::display is
+ * not virtual... And you cannot use TQLCDNumber::intValue() to retrieve
* the given value.
*/
@@ -182,7 +182,7 @@ private:
//-----------------------------------------------------------------------------
/**
- * This widget holds a list of @ref QLCDNumber arranged in a vertical layout.
+ * This widget holds a list of @ref TQLCDNumber arranged in a vertical layout.
* It also shows a label at the top of the list.
*
@@ -195,55 +195,55 @@ public:
*
* @param title is the content of the top label.
- * @param parent passed to the QWidget constructor
- * @param name passed to the QWidget constructor
+ * @param parent passed to the TQWidget constructor
+ * @param name passed to the TQWidget constructor
*/
@@ -195,55 +195,55 @@ public:
~KGameLCDList();
/**
- * Append a QLCDNumber at the bottom of the list.
- * The QLCDNumber should have the KGameLCDList as parent.
+ * Append a TQLCDNumber at the bottom of the list.
+ * The TQLCDNumber should have the KGameLCDList as parent.
*/
@@ -195,55 +195,55 @@ public:
/**
- * Append a QLCDNumber at the bottom of the list.
- * The QLCDNumber should have the KGameLCDList as parent.
+ * Append a TQLCDNumber at the bottom of the list.
+ * The TQLCDNumber should have the KGameLCDList as parent.
*/
@@ -195,55 +195,55 @@ public:
/**
- * Delete all @ref QLCDNumber and clear the list.
+ * Delete all @ref TQLCDNumber and clear the list.
*/
void clear();
@@ -195,55 +195,55 @@ public:
/**
- * @return the QLCDNumber at index @param i
+ * @return the TQLCDNumber at index @param i
*/
@@ -195,55 +195,55 @@ public:
/**
- * @return the number of QLCDNumber in the list.
+ * @return the number of TQLCDNumber in the list.
*/
uint size() const { return _lcds.size(); }